<template>
  <template v-if="props.link?.has_password">
    <div
      :style="{ backgroundImage: `url('${props.appearance.background}')` }"
      class="relative flex min-h-screen items-center justify-center bg-gray-100 bg-cover bg-center p-6"
    >
      <div class="mx-auto flex w-full max-w-2xl flex-col items-center gap-10 rounded-md bg-white p-6 shadow md:flex-row">
        <div>
          <SecureLoginIllustration class="mx-auto h-28 w-auto" />
        </div>
        <div class="grow">
          <FormGroup @submit="submit">
            <div class="font-medium text-gray-800">
              {{ $t("app.links.visit.protected.title") }}
            </div>
            <AlertError v-if="form.errors && form.errors?.unknown">
              {{ form.errors.unknown }}
            </AlertError>
            <FormInput
              id="password"
              :errors="form.errors.password"
            >
              <FormLabel>{{ $t("app.links.visit.protected.form.password") }}</FormLabel>
              <FormText
                v-model="form.values.password"
                autocomplete="off"
                name="password"
                required
                type="password"
              />
            </FormInput>
            <div>
              <FormSubmit
                :processing="form.isFetching"
                class="btn btn-primary ml-auto"
              >
                {{ $t("app.links.visit.protected.form.submit") }}
              </FormSubmit>
            </div>
          </FormGroup>
        </div>
      </div>
    </div>
  </template>
</template>

<script lang="ts" setup>
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import useSnowflake from "@/js/contexts/shared/composables/useSnowflake";
import SecureLoginIllustration from "@/svg/illustrations/secure-login.svg?component";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import useForm from "@/js/contexts/shared/composables/useForm";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";

const { props } = useSnowflake();

const csrfFetch = useFetch("/sanctum/csrf-cookie");

const form = useForm({
  password: "",
});

const submit = () => {
  csrfFetch.get().then(() => {
    form.post(`${props.link?.code}/check-password`, {
      onError: () => form.reset("password"),
      onSuccess: () => location.replace(String(props.link?.url)),
    });
  });
};
</script>
